/*
 * Spirits id and mongo _id handling
 */

"use strict";

// Mongo DB adapter
const MongoDbAdapter = require("moleculer-db-adapter-mongo");

// Id generator
const { v4: uuidv4 } = require('uuid');

class SpiritsMongoDbAdapter extends MongoDbAdapter {

	/**
	 * Redefinition insert mongo adapter: insert an entity with Spirits id and mongo _id handling.
	 *
	 * @param {Object} entity
	 * @returns {Object} entity created with a new id
	 *
	 * @memberof SpiritsMongoDbAdapter
	 */
	async insert(entity) {
		entity.id = entity.id ? entity.id : uuidv4();
		entity = await super.insert(entity);
		delete entity._id;
		return entity;
	}

	/**
	 * Redefinition find mongo adapter: hide mongo_id
	 * 
	 * @param {*} params 
	 */
	async find(params) {
		let entities = await super.find(params);
		return entities.map(({ _id, ...keepAttrs }) => keepAttrs);
	}

	/**
	 * Redefinition findOne mongo adapter: hide mongo_id
	 * 
	 * @param {*} params 
	 */
	async findOne(params) {
		let entity = await super.findOne(params);
		delete entity._id;
		return entity;
	}

	/**
	 * Redefinition updateById mongo adapter: hide mongo_id
	 * 
	 * @param {*} id 
	 * @param {*} params 
	 */
	async updateById(id, params) {
		let entity = await super.findOne({ id: id });
		return await super.updateById(entity._id, params);
	}

}

module.exports = SpiritsMongoDbAdapter;
