/*
 * errors-handler
 */

"use strict";

// Log
const util = require('util');

// Moleculer errors
const moleculer = require('moleculer');
const moleculerErrors = [
	"MoleculerError",
	"MoleculerRetryableError",
	"MoleculerServerError",
	"MoleculerClientError",
	"ValidationError",
	"ServiceNotFoundError",
	"ServiceNotAvailableError",
	"RequestTimeoutError",
	"RequestSkippedError",
	"RequestRejectedError",
	"QueueIsFullError",
	"MaxCallLevelError",
	"GracefulStopTimeoutError",
	"ProtocolVersionMismatchError",
	"InvalidPacketDataError",
	"ServiceSchemaError",
	"BrokerOptionsError"
]

module.exports = function () {

	const errorsHandlerMixIn = {

		methods: {

			/**
			 * Just create a generic Moleculer framework error and log when it's not yet handle.
			 * @param {*} error 
			 */
			handle(error) {
				let thrownOut = moleculerErrors.find(moleculerError => error.name == moleculerError);
				// Moleculer specific
				if (thrownOut)
					return error;
				// Generic
				console.error(util.inspect(error, false, 2, true));
				return new moleculer.Errors.MoleculerError("Spirits error not handled", 500, "GENERIC", {});
			}
		},

		/**
		 * Mixin init.
		 */
		async created() {
			console.info("errors-handler init....");
			console.info("errors-handler OK!");
		}

	};

	return errorsHandlerMixIn;
};
