/*
 * moleculer-firebase-admin
 * Initiate fire base admin to storage.
 */

"use strict";

// Firebase
const admin = require('firebase-admin');

// Paths
const appRoot = require('app-root-path');
const path = require('path');

module.exports = function (credentialFilePath, storageBucket, tempPath) {
	const firebaseMixIn = {

		methods: {
			/**
			 * Upload a file to firebase.
			 * @param {*} filePath File path.
			 */
			async storageUpload(filePath) {
				let file = await admin.storage().bucket().upload(filePath);
				return file[1].selfLink; // Get file object and return link.
			},

			/**
			 * Download file from firebase.
			 * 
			 * @param {*} uuid Spirits file name with id.
			 * @param {*} name Original file name.
			 */
			async storageDownload(uuid, name) {
				try {
					const filePath = path.join(appRoot.path, tempPath, name);
					await admin.storage().bucket().file(uuid).download({ destination: filePath });
					return filePath;
				}
				catch (e) {
					console.error(e);
				}
			}
		},

		/**
		 * Mixin init.
		 */
		async created() {
			console.info("moleculer-firebase-admin initializating ...");
			credentialFilePath = path.join(appRoot.path, credentialFilePath);
			const credentialFile = require(credentialFilePath);
			admin.initializeApp({
				credential: admin.credential.cert(credentialFile),
				storageBucket: storageBucket
			});
			console.info("moleculer-firebase-admin OK!");
		}
	};

	return firebaseMixIn;
};
